import { 
  select, 
  csv, 
  scaleLinear,
  scaleTime,
  max,
  axisLeft,
  axisBottom,
  extent
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {

  const title = 'A week in San Francisco';
  
  const xValue = d => d.timestamp;
  const xAxisLabel = 'Time';
  
  const yValue = d => d.temperature;
  const yAxisLabel = 'Temperature';
  
  const circleRadius = 6;
  
  
  const margin = {top: 60, right: 40, bottom: 88, left: 120};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  	.nice();
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([0, innerHeight].reverse())
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.append('g')
    .call(yAxis);
  
  yAxisG.select('.domain').remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
	g.selectAll('circle').data(data)
  	.enter().append('circle')
  		.attr('cy', d => yScale(yValue(d)))
  		.attr('cx', d => xScale(xValue(d)))
  		.attr('r', circleRadius);
  
  g.append('text')
  	.text(title)
  	.attr('y', -10)
  	.attr('class', 'plot-title');
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 70)
  	.text(xAxisLabel)
  	.attr('fill', 'black')
  	.attr('x', innerWidth / 2);
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -63)
  	.text(yAxisLabel)
  	.attr('fill', 'black')
  	.attr('transform', `rotate(-90)`)
  	.attr('x', -innerHeight/2)
  	.attr('text-anchor', 'middle');
  
}

csv('https://gist.githubusercontent.com/curran/60b40877ef898f19aeb8/raw/9476be5bd15fb15a6d5c733dd79788fb679c9be9/week_temperature_sf.csv')
  .then(data => {
    data.forEach(d => {
      d.temperature = +d.temperature;
      d.timestamp = new Date(d.timestamp);
    });
    render(data);
	});



























